@@ -34,6 +34,7 @@ my $ignoreKeys;
 my $mainTree;
 my @sessionTypes;
 my @simpleHashKeys;
+my @doubleHashKeys;
 
 my $attributes = Lemonldap::NG::Manager::Build::Attributes::attributes();
 my $jsonEnc    = JSON->new()->allow_nonref;
@@ -148,7 +149,7 @@ sub run {
     open F, ">", $self->managerConstantsFile or die($!);
     my $exportedVars =
         '$'
-      . join( 'Keys $', 'simpleHash', 'specialNode', sort keys %cnodesRe )
+      . join( 'Keys $', 'simpleHash', 'specialNode', 'doubleHash', sort keys %cnodesRe )
       . 'Keys $specialNodeHash @sessionTypes';
     print F <<EOF;
 # This file is generated by $module. Don't modify it by hand
@@ -179,6 +180,11 @@ EOF
     # Reinitialize $attributes
     $attributes = Lemonldap::NG::Manager::Build::Attributes::attributes();
 
+    $ra = Regexp::Assemble->new;
+    foreach (@doubleHashKeys) {
+        $ra->add($_);
+    }
+    print F "our \$doubleHashKeys = '" . $ra->as_string . "';\n";
     $ra = Regexp::Assemble->new;
     foreach (@simpleHashKeys) {
         $ra->add($_);
@@ -473,6 +479,9 @@ sub scanTree {
                     push @simpleHashKeys, $leaf;
                 }
             }
+            elsif ( $attr->{type} eq 'doubleHash' and $leaf !~ $reIgnoreKeys ) {
+                push @doubleHashKeys, $leaf;
+            }
             else {
                 if ( $prefix and !$jleaf->{get} ) {
                     $jleaf->{get} = $prefix . $jleaf->{title};
