@@ -24,6 +24,8 @@ use Mouse;
 use Lemonldap::NG::Manager::Constants;
 use Lemonldap::NG::Manager::Attributes;
 
+our $VERSION = '1.9.3';
+
 # High debugging for developpers, set this to 1
 use constant HIGHDEBUG => 0;
 
@@ -372,7 +374,23 @@ sub _scanNodes {
                 elsif ( $target =~ /^oidc(?:O|R)PMetaDataOptions/ ) {
                     my $optKey = $&;
                     hdebug "  $base sub key: $target";
-                    if ( $target =~
+                    if ( $target eq 'oidcRPMetaDataOptionsExtraClaims' ) {
+                        if ( $leaf->{cnodes} ) {
+                            hdebug('    unopened');
+                            $self->newConf->{$target}->{$key} =
+                              $self->refConf->{$target}->{$key} // {};
+                        }
+                        elsif ($h) {
+                            hdebug('    opened');
+                            $self->set( $target, $key, $leaf->{title},
+                                $leaf->{data} );
+                        }
+                        else {
+                            hdebug("  $target: looking for subnodes");
+                            $self->_scanNodes($subNodes);
+                        }
+                    }
+                    elsif ( $target =~
                         /^(?:$oidcOPMetaDataNodeKeys|$oidcRPMetaDataNodeKeys)/o
                       )
                     {
@@ -612,7 +630,7 @@ sub _scanNodes {
         ####################
         # Other hash nodes #
         ####################
-        elsif ( $leaf->{title} =~ $simpleHashKeys
+        elsif ( $leaf->{title} =~ /^$simpleHashKeys$/o
             and not $leaf->{title} eq 'applicationList' )
         {
             hdebug( $leaf->{title} );
@@ -667,6 +685,75 @@ sub _scanNodes {
             next;
         }
 
+        # Double hash nodes
+        elsif ( $leaf->{title} =~ /^$doubleHashKeys$/ ) {
+            hdebug( $leaf->{title} );
+            my @oldHosts = (
+                ref( $self->refConf->{$name} )
+                ? ( keys %{ $self->refConf->{$name} } )
+                : ()
+            );
+            $self->newConf->{$name} = {};
+            unless ( defined $leaf->{data} ) {
+                hdebug('  unopened');
+                $self->newConf->{$name} = $self->refConf->{$name};
+                next;
+            }
+            foreach my $getHost ( @{ $leaf->{data} } ) {
+                my $change = 0;
+                my @oldKeys;
+                my $host = $getHost->{k};
+                hdebug("  looking at host: $host");
+                $self->newConf->{$name}->{$host} = {};
+                unless ( defined $self->refConf->{$name}->{$host} ) {
+                    $self->confChanged(1);
+                    $change++;
+                    push @{ $self->changes }, { key => $name, new => $host };
+                    hdebug("    $host is new");
+                }
+                else {
+                    @oldHosts = grep { $_ ne $host } @oldHosts;
+                    @oldKeys = keys %{ $self->refConf->{$name}->{$host} };
+                }
+                foreach my $prm ( @{ $getHost->{h} } ) {
+                    $self->newConf->{$name}->{$host}->{ $prm->{k} } = $prm->{v};
+                    if (
+                        !$change
+                        and (
+                            not defined(
+                                $self->refConf->{$name}->{$host}->{ $prm->{k} }
+                            )
+                            or $self->newConf->{$name}->{$host}->{ $prm->{k} }
+                            ne $self->refConf->{$name}->{$host}->{ $prm->{k} }
+                        )
+                      )
+                    {
+                        $self->confChanged(1);
+                        hdebug("    key $prm->{k} has been changed");
+                        push @{ $self->changes },
+                          { key => "$name/$host", new => $prm->{k} };
+                    }
+                    elsif ( !$change ) {
+                        @oldKeys = grep { $_ ne $prm->{k} } @oldKeys;
+                    }
+                }
+                if (@oldKeys) {
+                    $self->confChanged(1);
+                    hdebug( "  old keys: " . join( ' ', @oldKeys ) );
+                    push @{ $self->changes },
+                      { key => "$name/$host", old => $_ }
+                      foreach (@oldKeys);
+                }
+            }
+            if (@oldHosts) {
+                $self->confChanged(1);
+                hdebug( "  old hosts " . join( ' ', @oldHosts ) );
+                push @{ $self->changes }, { key => "$name", old => $_ }
+                  foreach (@oldHosts);
+            }
+            next;
+        }
+
         ###############
         # Other nodes #
         ###############
@@ -807,6 +894,7 @@ sub _unitTest {
     my $attrs = &Lemonldap::NG::Manager::Attributes::attributes();
     my $res   = 1;
     foreach my $key ( keys %$conf ) {
+        hdebug("Testing $key");
         my $attr = $attrs->{$key};
         my $type = $types->{ $attr->{type} };
         die "Unkown type $attr->{type}" unless ( $type or $attr->{test} );
@@ -825,7 +913,7 @@ sub _unitTest {
             }
 
             # Hash parameters
-            if ( $key =~ $simpleHashKeys ) {
+            if ( $key =~ /^$simpleHashKeys$/o ) {
                 $conf->{$key} //= {};
                 unless ( ref $conf->{$key} eq 'HASH' ) {
                     push @{ $self->errors },
@@ -838,7 +926,9 @@ sub _unitTest {
 
                 #TODO
             }
-            if ( $key =~ $simpleHashKeys or $attr->{type} =~ /Container$/ ) {
+            if (   $key =~ /^(?:$simpleHashKeys|$doubleHashKeys)$/o
+                or $attr->{type} =~ /Container$/ )
+            {
                 my $keyMsg = $attr->{keyMsgFail} // $type->{keyMsgFail};
                 my $msg    = $attr->{msgFail}    // $type->{msgFail};
                 $res = 0
